<html>
    <title>directSMS PHP API</title>
    <body>
        <h2>directSMS PHP API Code Sample</h2>
        <pre>
<?php

    /****************************************************************************/
    /*                                                                          */
    /* Desc:        Sample to show the operations available through the         */
    /*              directSMS PHP API                                           */
    /*                                                                          */
    /* Version:     1.3.7                                                       */
    /* Copyright:   Copyright (c) 2003 directSMS Pty Ltd. All rights reserved   */
    /* Rel. Date:   17/08/2014                                                  */
    /*                                                                          */
    /****************************************************************************/

    // Load the sms_connection class
    require_once("sms_connection.php");

    /**
     * A function to run the different operations available
     * through the directSMS PHP API
     *
     * TODO - Set the correct destination numbers
     *
     * @param   $username   Your directSMS username
     * @param   $password   Your directSMS password
     */
    function test_sms_operations($username, $password)
    {
        // Create a new connection
        $conn = new sms_connection();

        // Check if there are any problems
        if($conn->is_error())
        {
            // Could not talk to the server, stop
            print("ERROR: " . $conn->get_error() . "\n");
            return;
        }

        // Login to start a session using your directSMS
        // username and password
        if(!$conn->connect($username, $password))
        {
            // Login failed, show the error and stop
            print("ERROR: " . $conn->get_error() . "\n");
            return;
        }

        // Get the current balance
        $credits = $conn->get_balance();

        // Use the is_error() method to check for any problems
        if($conn->is_error())
        {
            // Show the error encountered and stop
            print("ERROR: " . $conn->get_error() . "\n");
            return;
        }

        // Show the balance
        print("Current credit balance = " . $credits . " SMS credit(s)\n");

        // Create a new message
        $message  = "This is a test message from the directSMS gateway";
        $mobiles  = array("0418641804", "0418719625");

        // Send a 1-way message with the Sender ID "test.123"
        // 1-way messages can only have a Sender ID made of the
        // characters a-z, A-Z, . or 0-9 only. The Sender ID must
        // not exceed 11 characters
        $id = $conn->send_one_way_sms($message, $mobiles, "test.123");

        if($conn->is_error())
        {
            print("Error sending 1-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show id
        print("1-way message sent to " . count($mobiles) . " mobile(s), id = $id\n");

        // Send a 2-way sms message with the messageid "my-id". We can
        // use that id to search for replies to this message later
        $id = $conn->send_two_way_sms($message, $mobiles, "my-id");

        if($conn->is_error())
        {
            print("Error sending 2-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show id
        print("2-way message sent to " . count($mobiles) . " mobile(s), id = $id\n");

        // Retrieve any replies to the 2-way sms submitted just now
        // but do not mark any of them as read so we can fetch them
        // again later
        $replies = $conn->get_reply_sms(null, "my-id");
        print(count($replies) . " 2-way reply messages retrieved\n");

        // Display the replies
        for($i = 0; $i < count($replies); $i++)
        {
            // Print each reply on a separate line.
            print($replies[$i]->to_string() . "\n");
        }

        // Lets retrieve any new inbound messages that have come in
        // but dont mark any of them as read
        $inbound_sms = $conn->get_inbound_sms();
        print(count($inbound_sms) . " inbound messages retrieved\n");

        // Display the messages
        for($i = 0; $i < count($inbound_sms); $i++)
        {
            // Print each message on a separate line.
            print($inbound_sms[$i]->to_string() . "\n");
        }

        // Schedule a message to go out at 11 AM on Jan 1
        // of next year saying happy new year
        $time = mktime(11, 0, 0, 1, 1, date("Y") + 1);
        $message = "Happy new year from the team @ directSMS team";
        $mobiles = array("0418641804", "0418719625");

        // Save on the server
        $id = $conn->schedule_one_way_sms($message, $mobiles, "directSMS", $time);

        if($conn->is_error())
        {
            print("Error scheduling 1-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show the id
        print("Scheduled a 1-way message to " . count($mobiles) . " mobile(s), id = $id\n");

        // Cancel the message we just created
        $id = $conn->cancel_scheduled_sms($id);

        if($conn->is_error())
        {
            print("Error cancelling scheduled 1-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show the id
        print("Cancelled scheduled 1-way message with id = $id\n");

        // Send a long 1-way SMS (max of 2 segments)
        $ids = $conn->send_one_way_sms("This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS.",
                                       $mobiles, "directSMS", 2);

        print("Long 1-way Message sent to " . count($mobiles) . " people. The ids of the message segnemnts were:\n");
        print_r($ids);

        // Send a long 2-way SMS (max of 2 segments)
        $ids = $conn->send_two_way_sms("This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS. This is a long SMS.",
                                       $mobiles, "My Unique Message ID", 2);

        print("Long 2-way Message sent to " . count($mobiles) . " people. The ids of the message segnemnts were:\n");
        print_r($ids);

        // Lets look at our credits again
        print("Updated credit balance = " . $conn->get_balance() . " credit(s)\n");

        // Now disconnect
        $conn->disconnect();
    }

    /**
     * Function to send unicode messages
     *
     * TODO - Set the correct destination numbers
     *
     * @param   $username   Your directSMS username
     * @param   $password   Your directSMS password
     */
    function test_unicode_send($username, $password)
    {
        // Create a new connection
        $conn = new sms_connection();

        // Check if there are any problems
        if($conn->is_error())
        {
            // Could not talk to the server, stop
            print("ERROR: " . $conn->get_error() . "\n");
            return;
        }

        // Login to start a session using your directSMS
        // username and password
        if(!$conn->connect($username, $password))
        {
            // Login failed, show the error and stop
            print("ERROR: " . $conn->get_error() . "\n");
            return;
        }

        // Create a new message
        $message = "Hello World - 你好世界";
        $mobiles = array("0418641804");

        // Send a 1-way message with the Sender ID "test.123"
        // 1-way messages can only have a Sender ID made of the
        // characters a-z, A-Z, . or 0-9 only. The Sender ID must
        // not exceed 11 characters
        $id = $conn->send_one_way_sms($message, $mobiles, "test.123", 1, true);

        if($conn->is_error())
        {
            print("Error sending 1-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show the id
        print("1-way message sent to " . count($mobiles) . " mobile(s), id = $id\n");

        // Send a 2-way message with the ID "test.123"
        $id = $conn->send_two_way_sms($message, $mobiles, "test.123", 1, true);

        if($conn->is_error())
        {
            print("Error sending 2-way message: " . $conn->get_error() . "\n");
            return;
        }

        // Show the id
        print("2-way message sent to " . count($mobiles) . " mobile(s), id = $id\n");

        // Now disconnect
        $conn->disconnect();
    }

    // Run all non Unicode tests
    test_sms_operations("my_user", "P@ssw0rd");

    // Send some test Unicode messages
    // test_unicode_send("my_user", "P@ssw0rd");
?>
        </pre>
    </body>
</html>
